/v1/projects/{project_id}/vpcs/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/nio — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Vpcs »

# /v1/projects/{project_id}/vpcs/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/nio

Contents

- /v1/projects/{project_id}/vpcs/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/nio
  - POST /v1/projects/{project_id}/vpcs/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/nio
    - Parameters
    - Response status codes
  - DELETE /v1/projects/{project_id}/vpcs/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/nio
    - Parameters
    - Response status codes

## POST /v1/projects/{project_id}/vpcs/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/nio

Add a NIO to a VPCS instance

### Parameters

- adapter_number: Network adapter where the nio is located
- port_number: Port where the nio should be added
- vm_id: UUID for the instance
- project_id: UUID for the project

### Response status codes

- 400: Invalid request
- 201: NIO created
- 404: Instance doesn’t exist

## DELETE /v1/projects/{project_id}/vpcs/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/nio

Remove a NIO from a VPCS instance

### Parameters

- adapter_number: Network adapter where the nio is located
- port_number: Port from where the nio should be removed
- vm_id: UUID for the instance
- project_id: UUID for the project

### Response status codes

- 400: Invalid request
- 404: Instance doesn’t exist
- 204: NIO deleted

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Vpcs »